AppLocalizations class abstract

Callers can lookup localized strings with an instance of AppLocalizations returned by AppLocalizations.of(context).

Applications need to include AppLocalizations.delegate() in their app's localizationDelegates list, and the locales they support in the app's supportedLocales list. For example:

import 'l10n/app_localizations.dart';

return MaterialApp(
  localizationsDelegates: AppLocalizations.localizationsDelegates,
  supportedLocales: AppLocalizations.supportedLocales,
  home: MyApplicationHome(),
);

Update pubspec.yaml

Please make sure to update your pubspec.yaml to include the following packages:

dependencies:
  # Internationalization support.
  flutter_localizations:
    sdk: flutter
  intl: any # Use the pinned version from flutter_localizations

  # Rest of dependencies

iOS Applications

iOS applications define key application metadata, including supported locales, in an Info.plist file that is built into the application bundle. To configure the locales supported by your app, you’ll need to edit this file.

First, open your project’s ios/Runner.xcworkspace Xcode workspace file. Then, in the Project Navigator, open the Info.plist file under the Runner project’s Runner folder.

Next, select the Information Property List item, select Add Item from the Editor menu, then select Localizations from the pop-up menu.

Select and expand the newly-created Localizations item then, for each locale your application supports, add a new item and select the locale you wish to add from the pop-up menu in the Value field. This list should be consistent with the languages listed in the AppLocalizations.supportedLocales property.

Implementers

Constructors

AppLocalizations(String locale)

Properties

add String
Button label for add action
no setter
addAccount String
Button text to add a new account
no setter
addCashuTooltip String
Tooltip for add Cashu wallet button
no setter
addCashuWallet String
Label for add Cashu wallet button
no setter
addCashuWalletTitle String
Title for add Cashu wallet dialog
no setter
addLnurlTooltip String
Tooltip for add LNURL wallet button
no setter
addLnurlWallet String
Label for add LNURL wallet button
no setter
addLnurlWalletTitle String
Title for add LNURL wallet dialog
no setter
addNwcTooltip String
Tooltip for add NWC wallet button
no setter
addNwcWallet String
Label for add NWC wallet button
no setter
addNwcWalletTitle String
Title for add NWC wallet dialog
no setter
addWalletTitle String
Title for add wallet dialog
no setter
aiEmbeddings String
Nostr event kind 1987
no setter
albyGoOption String
Label for Alby Go option
no setter
amount String
Label for amount input
no setter
amountHint String
Hint for amount input
no setter
appCurationSets String
Nostr event kind 30267
no setter
applicationSpecificData String
Nostr event kind 30078
no setter
badgeAward String
Nostr event kind 8
no setter
badgeDefinition String
Nostr event kind 30009
no setter
balance String
Label for balance display
no setter
blobsStoredOnMediaservers String
Nostr event kind 24242
no setter
blockedRelaysList String
Nostr event kind 10006
no setter
bookmarkList String
Nostr event kind 10003
no setter
bookmarkSets String
Nostr event kind 30003
no setter
browserExtension String
Label for browser extension login section
no setter
budgetDaily String
Daily budget renewal period
no setter
budgetMonthly String
Monthly budget renewal period
no setter
budgetNever String
Never renews budget
no setter
budgetWeekly String
Weekly budget renewal period
no setter
budgetYearly String
Yearly budget renewal period
no setter
bunker String
Label for bunker login section
no setter
bunkerAuthentication String
Title for bunker authentication toast
no setter
calendar String
Nostr event kind 31924
no setter
calendarEventRsvp String
Nostr event kind 31925
no setter
cameraNotAvailable String
Message shown when camera is not available
no setter
cancel String
Button label for cancel action
no setter
cashuOption String
Label for Cashu wallet option
no setter
cashuWallet String
Label for Cashu wallet type
no setter
cashuWalletAdded String
Success message when Cashu wallet is added
no setter
cashuWalletEvent String
Nostr event kind 17375
no setter
cashuWalletHistory String
Nostr event kind 7376
no setter
cashuWalletProofs String
Nostr event kind 7375
no setter
cashuWalletToken String
Nostr event kind 7374
no setter
cashuWalletTypeSubtitle String
Subtitle for Cashu wallet type option
no setter
cashuWalletTypeTitle String
Title for Cashu wallet type option
no setter
categorizedBookmarkList String
Nostr event kind 30001
no setter
categorizedPeopleList String
Nostr event kind 30000
no setter
categorizedRelayList String
Nostr event kind 30002
no setter
channelCreation String
Nostr event kind 40
no setter
channelHideMessage String
Nostr event kind 43
no setter
channelMessage String
Nostr event kind 42
no setter
channelMetadata String
Nostr event kind 41
no setter
channelMuteUser String
Nostr event kind 44
no setter
chatMessage String
Nostr event kind 9
no setter
chessPgn String
Nostr event kind 64
no setter
chooseNwcMethod String
Prompt to choose NWC connection method
no setter
chooseWalletType String
Prompt to choose wallet type
no setter
classifiedListing String
Nostr event kind 30402
no setter
clientAuthentication String
Nostr event kind 22242
no setter
close String
Label for close button
no setter
codeSnippet String
Nostr event kind 1337
no setter
coinjoinPool String
Nostr event kind 2022
no setter
comment String
Nostr event kind 1111
no setter
communitiesList String
Nostr event kind 10004
no setter
communityDefinition String
Nostr event kind 34550
no setter
communityPostApproval String
Nostr event kind 4550
no setter
connect String
Button text to connect with browser extension
no setter
connectNwcTitle String
Title for NWC connection dialog
no setter
copied String
Message shown when copied
no setter
copy String
Button text to copy to clipboard
no setter
copyAgain String
Label for copy again button
no setter
create String
Label for create button
no setter
createAccount String
Button text for creating a new account
no setter
createInvoiceTitle String
Title for create invoice dialog
no setter
createOrUpdateProduct String
Nostr event kind 30018
no setter
createOrUpdateStall String
Nostr event kind 30017
no setter
createToken String
Label for create token button
no setter
curatedPublicationDraft String
Nostr event kind 30041
no setter
curatedPublicationItem String
Nostr event kind 30040
no setter
curationSets String
Nostr event kind 30004
no setter
dateBasedCalendarEvent String
Nostr event kind 31922
no setter
defaultForReceiving String
Menu label for wallet already default for receiving
no setter
defaultForSending String
Menu label for wallet already default for sending
no setter
defaultWalletForReceivingTooltip String
Tooltip shown on receiving default ribbon
no setter
defaultWalletForSendingTooltip String
Tooltip shown on sending default ribbon
no setter
delete String
Label for delete action
no setter
deleteWallet String
Label for delete wallet option
no setter
deleteWalletConfirmation String
Title for delete wallet confirmation dialog
no setter
deleteWalletConfirmationMessage String
Message for delete wallet confirmation dialog
no setter
directMessage String
Nostr event kind 14
no setter
dmRelayList String
Nostr event kind 10050
no setter
draftClassifiedListing String
Nostr event kind 30403
no setter
draftEvent String
Nostr event kind 31234
no setter
draftLongFormContent String
Nostr event kind 30024
no setter
emojiSets String
Nostr event kind 30030
no setter
encryptedDirectMessages String
Nostr event kind 4
no setter
enterLnurlIdentifier String
Prompt for LNURL identifier input
no setter
enterMintUrl String
Prompt for mint URL input
no setter
errorCreatingWallet String
Error message when creating NWC wallet fails
no setter
eventDeletionRequest String
Nostr event kind 5
no setter
extension String
Label for browser extension account type
no setter
externalReference String
Nostr event kind 31
no setter
failedToAddMint String
Error message when adding Cashu wallet fails
no setter
faucet String
Tab label for faucet option
no setter
faucetOption String
Label for faucet option
no setter
favoritesList String
Nostr event kind 10012
no setter
feed String
Nostr event kind 31890
no setter
fileMessage String
Nostr event kind 15
no setter
fileMetadata String
Nostr event kind 1063
no setter
fileStorageServerList String
Nostr event kind 10096
no setter
follows String
Nostr event kind 3
no setter
fromYourProfile String
Label indicating a value comes from user's profile
no setter
genericRepost String
Nostr event kind 16
no setter
geocacheCreate String
Nostr event kind 7516
no setter
geocacheListing String
Nostr event kind 37516
no setter
geocacheUpdate String
Nostr event kind 7517
no setter
getStarted String
Button text to get started with Nostr
no setter
giftWrap String
Nostr event kind 1059
no setter
gitIssue String
Nostr event kind 1621
no setter
gitIssueUpdate String
Nostr event kind 1622
no setter
gitPatch String
Nostr event kind 1617
no setter
gitPullRequest String
Nostr event kind 1618
no setter
gitStatusUpdate String
Nostr event kind 1619
no setter
groupAdminMetadata String
Nostr event kind 39001
no setter
groupAdminsList String
Nostr event kind 39003
no setter
groupChatMessage String
Nostr event kind 39007
no setter
groupChatThread String
Nostr event kind 39008
no setter
groupChatThreadedReply String
Nostr event kind 10
no setter
groupControlEvent String
Nostr event kinds 9000-9030
no setter
groupMemberMetadata String
Nostr event kind 39002
no setter
groupMembersList String
Nostr event kind 39004
no setter
groupMetadata String
Nostr event kind 39000
no setter
groupPermissions String
Nostr event kind 39006
no setter
groupPinned String
Nostr event kind 39009
no setter
groupRoles String
Nostr event kind 39005
no setter
groupThreadReply String
Nostr event kind 12
no setter
handlerInformation String
Nostr event kind 31990
no setter
handlerRecommendation String
Nostr event kind 31989
no setter
hardcopyReference String
Nostr event kind 32
no setter
hashCode int
The hash code for this object.
no setterinherited
highlights String
Nostr event kind 9802
no setter
httpAuth String
Nostr event kind 27235
no setter
install String
Button text to install browser extension
no setter
interestSets String
Nostr event kind 30015
no setter
interestsList String
Nostr event kind 10015
no setter
internalReference String
Nostr event kind 30
no setter
invalidAddress String
Error message for invalid nostr address
no setter
invalidFaucetResponse String
Error message for invalid faucet response
no setter
invalidNwcQrCode String
Error message for invalid NWC QR code
no setter
invalidNwcUri String
Error message for invalid NWC URI
no setter
invoice String
Label for invoice input
no setter
invoiceCreatedAndCopied String
Success message when invoice is created and copied
no setter
invoiceCreatedMessage String
Message shown when invoice is created
no setter
invoiceHint String
Hint for invoice input
no setter
invoicePaid String
Success message when invoice is paid
no setter
invoiceTrackingTitle String
Title for invoice tracking dialog
no setter
jobFeedback String
Nostr event kind 7000
no setter
jobRequest String
Nostr event kinds 5000-5999
no setter
jobResult String
Nostr event kinds 6000-6999
no setter
keyPackageRelayList String
Nostr event kind 10051
no setter
kindMuteSets String
Nostr event kind 30007
no setter
label String
Nostr event kind 1985
no setter
lightningPubRpc String
Nostr event kind 21000
no setter
limitsUnavailable String
Message shown when limits are unavailable
no setter
linkSet String
Nostr event kind 31388
no setter
liveChatMessage String
Nostr event kind 1311
no setter
liveEvent String
Nostr event kind 30311
no setter
lnurlIdentifierHint String
Hint for LNURL identifier input
no setter
lnurlOption String
Label for LNURL wallet option
no setter
lnurlWallet String
Label for LNURL wallet type
no setter
lnurlWalletAdded String
Success message when LNURL wallet is added
no setter
lnurlWalletTypeSubtitle String
Subtitle for LNURL wallet type option
no setter
lnurlWalletTypeTitle String
Title for LNURL wallet type option
no setter
localeName String
final
loginWithAmber String
Button text to login with Amber
no setter
logout String
Button text to logout from the application
no setter
longFormContent String
Nostr event kind 30023
no setter
manual String
Tab label for manual option
no setter
manualOption String
Label for manual connection option
no setter
marketplaceBid String
Nostr event kind 1021
no setter
marketplaceBidConfirmation String
Nostr event kind 1022
no setter
marketplaceUiUx String
Nostr event kind 30019
no setter
mediaFollowsList String
Nostr event kind 10019
no setter
mediaStarterPacks String
Nostr event kind 39092
no setter
mergeRequests String
Nostr event kind 818
no setter
mintAnnouncement String
Nostr event kind 38172
no setter
mintQuote String
Nostr event kind 38173
no setter
mintUrl String
Label for mint URL input
no setter
mintUrlHint String
Hint for mint URL input
no setter
mlsGroupEvent String
Nostr event kind 445
no setter
mlsKeyPackage String
Nostr event kind 443
no setter
mlsWelcome String
Nostr event kind 444
no setter
muteList String
Nostr event kind 10000
no setter
newHere String
Question asking if the user is new to the platform
no setter
newToNostr String
Question asking if the user is new to Nostr
no setter
noRecentTransactions String
Message shown when there are no recent transactions
no setter
nostrAddress String
Label for nostr address input field
no setter
nostrAddressHint String
Placeholder text for nostr address input field
no setter
nostrConnectEvent String
Nostr event kind 24133
no setter
nostrConnectUrl String
Title for nostr connect URL dialog
no setter
noWalletsAvailable String
Message shown when no wallets are available
no setter
noWalletsYet String
Message shown when there are no wallets
no setter
nsec String
Label for nsec (private key) account type
no setter
nutzap String
Nostr event kind 9321
no setter
nwcConnectionUri String
Label for NWC connection URI input
no setter
nwcConnectionUriHint String
Hint for NWC connection URI input
no setter
nwcFaucetDescription String
Description for NWC faucet
no setter
nwcOption String
Label for NWC wallet option
no setter
nwcWallet String
Label for NWC wallet type
no setter
nwcWalletAdded String
Success message when NWC wallet is added
no setter
nwcWalletSubtitle String
Subtitle for NWC wallet
no setter
nwcWalletTypeSubtitle String
Subtitle for NWC wallet type option
no setter
nwcWalletTypeTitle String
Title for NWC wallet type option
no setter
openTimestamps String
Nostr event kind 1040
no setter
orEnterManually String
Label for manual entry option
no setter
Status message when payment is complete
no setter
paste String
Label for paste action
no setter
pay String
Label for pay button
no setter
payInvoiceTitle String
Title for pay invoice dialog
no setter
paymentReceived String
Message shown when payment is received
no setter
peerToPeerOrder String
Nostr event kind 38383
no setter
pendingTransactions String
Title for pending transactions section
no setter
peopleFollowsList String
Nostr event kind 10020
no setter
pickColor String
Label for pick color option
no setter
picture String
Nostr event kind 20
no setter
pinList String
Nostr event kind 10001
no setter
pleaseEnterInvoice String
Error message for empty invoice
no setter
pleaseEnterMintUrl String
Error message for empty mint URL
no setter
pleaseEnterToken String
Error message for empty token
no setter
pleaseEnterValidAmount String
Error message for invalid amount
no setter
pleaseEnterValidIdentifier String
Error message for invalid LNURL identifier
no setter
poll String
Nostr event kind 1068
no setter
pollResponse String
Nostr event kind 1018
no setter
privateEventsList String
Nostr event kind 10013
no setter
privateKey String
Label for private key input field
no setter
privateKeyHint String
Placeholder text for private key input field
no setter
problemTracker String
Nostr event kind 1971
no setter
productSoldAsAuction String
Nostr event kind 30020
no setter
profileBadges String
Nostr event kind 30008
no setter
promptReference String
Nostr event kind 33
no setter
proxyAnnouncement String
Nostr event kind 10377
no setter
publicChatsList String
Nostr event kind 10005
no setter
publicKey String
Label for public key input field
no setter
publicKeyHint String
Placeholder text for public key input field
no setter
reaction String
Nostr event kind 7
no setter
reactionToWebsite String
Nostr event kind 17
no setter
readOnly String
Label for read-only account type
no setter
receive String
Label for receive action
no setter
receiveByLightning String
Option for receiving by Lightning
no setter
receiveByLightningDescription String
Description for receive by Lightning option
no setter
receiveByToken String
Option for receiving by token
no setter
receiveByTokenDescription String
Description for receive by token option
no setter
receiveByTokenTitle String
Title for receive by token dialog
no setter
receiveOnlyWallet String
Label for receive-only wallet
no setter
receiveOptionsTitle String
Title for receive options sheet
no setter
recentActivityTitle String
Title for recent activity section
no setter
recentTransactions String
Title for recent transactions section
no setter
recommendRelay String
Nostr event kind 2
no setter
redirects String
Nostr event kind 30819
no setter
relayDiscovery String
Nostr event kind 30166
no setter
relayListMetadata String
Nostr event kind 10002
no setter
relayMonitorAnnouncement String
Nostr event kind 10166
no setter
relayReviews String
Nostr event kind 1986
no setter
releaseArtifactSets String
Nostr event kind 30063
no setter
renameWallet String
Label for rename wallet option
no setter
reporting String
Nostr event kind 1984
no setter
repositoryAnnouncement String
Nostr event kind 30617
no setter
repositoryStateAnnouncement String
Nostr event kind 30618
no setter
repost String
Nostr event kind 6
no setter
requestToVanish String
Nostr event kind 62
no setter
roomPresence String
Nostr event kind 10312
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sats String
Label for sats
no setter
save String
Label for save action
no setter
scanNwcInstructions String
Instructions for scanning NWC QR code
no setter
scanNwcQrCodeTitle String
Title for scanning NWC QR code
no setter
seal String
Nostr event kind 13
no setter
searchRelaysList String
Nostr event kind 10007
no setter
selected String
Label shown when a wallet is selected
no setter
send String
Label for send action
no setter
sendByLightning String
Option for sending by Lightning
no setter
sendByLightningDescription String
Description for send by Lightning option
no setter
sendByToken String
Option for sending by token
no setter
sendByTokenDescription String
Description for send by token option
no setter
sendOptionsTitle String
Title for send options sheet
no setter
setAsDefaultForReceiving String
Menu option to set wallet as default for receiving
no setter
setAsDefaultForSending String
Menu option to set wallet as default for sending
no setter
shortFormPortraitVideoEvent String
Nostr event kind 22
no setter
shortTextNote String
Nostr event kind 1
no setter
showNostrConnectQrcode String
Button text to show nostr connect QR code
no setter
slideSet String
Nostr event kind 30388
no setter
softwareApplication String
Nostr event kind 32267
no setter
starterPacks String
Nostr event kind 39089
no setter
startingBalance String
Label for starting balance input
no setter
startingBalanceHint String
Hint for starting balance input
no setter
status String
Nostr event kind 1630
no setter
statusDelete String
Nostr event kind 1632
no setter
statusReply String
Nostr event kind 1633
no setter
statusUpdate String
Nostr event kind 1631
no setter
tapToAddWallet String
Hint to add a wallet
no setter
thread String
Nostr event kind 11
no setter
tidalLogin String
Nostr event kind 9467
no setter
timeBasedCalendarEvent String
Nostr event kind 31923
no setter
token String
Label for token input
no setter
tokenCopied String
Message shown when token is copied
no setter
tokenCopiedToClipboard String
Success message when token is copied to clipboard
no setter
tokenHint String
Hint for token input
no setter
tokenReceived String
Success message when token is received
no setter
torrent String
Nostr event kind 2003
no setter
torrentComment String
Nostr event kind 2004
no setter
transportMethodAnnouncement String
Nostr event kind 11111
no setter
unableToConnect String
Error message when unable to connect to nostr address
no setter
unknownWalletType String
Label for unknown wallet type
no setter
userEmojiList String
Nostr event kind 10030
no setter
userGroups String
Nostr event kind 10009
no setter
userMetadata String
Nostr event kind 0
no setter
userServerList String
Nostr event kind 10063
no setter
userStatus String
Nostr event kind 30315
no setter
videoEvent String
Nostr event kind 21
no setter
videoSets String
Nostr event kind 30005
no setter
videoView String
Nostr event kind 34237
no setter
voiceMessage String
Nostr event kind 1222
no setter
voiceMessageComment String
Nostr event kind 1244
no setter
waitingForPayment String
Status message while waiting for payment
no setter
walletInfo String
Nostr event kind 13194
no setter
walletName String
Label for wallet name input
no setter
walletNameHint String
Hint for wallet name input
no setter
walletRenamed String
Message shown when wallet is renamed
no setter
walletRequest String
Nostr event kind 23194
no setter
walletResponse String
Nostr event kind 23195
no setter
walletsTitle String
Title for wallets section
no setter
webBookmarks String
Nostr event kind 39701
no setter
wikiArticle String
Nostr event kind 30818
no setter
zap String
Nostr event kind 9735
no setter
zapGoal String
Nostr event kind 9041
no setter
zapRequest String
Nostr event kind 9734
no setter

Methods

budgetRenewsIn(int days) String
Budget renewal information showing days until renewal
budgetUsedOf(int used, int total) String
Budget information showing used and total amount
error(String message) String
Error message for general errors
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
nwcFaucetWalletAdded(int balance) String
Success message when NWC faucet wallet is added
paymentFailed(String message) String
Error message when payment fails
receiveRange(int min, int max) String
Label showing receive range for LNURL wallet
tapToOpen(String url) String
Description for bunker authentication toast
toString() String
A string representation of this object.
inherited
unknownEventKind(int kind) String
Fallback for unknown event kinds

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) AppLocalizations?

Constants

delegate → const LocalizationsDelegate<AppLocalizations>
localizationsDelegates → const List<LocalizationsDelegate>
A list of this localizations delegate along with the default localizations delegates.
supportedLocales → const List<Locale>
A list of this localizations delegate's supported locales.