albyGoQrScanInstructions property
String
get
albyGoQrScanInstructions
Instructions shown beside the Alby Go wallet authorization QR code
In en, this message translates to: 'In Alby Go, tap Send, then scan this QR code.'
Implementation
String get albyGoQrScanInstructions;