newHere property
String
get
newHere
Question asking if the user is new to the platform
In en, this message translates to: 'Are you new here?'
Implementation
String get newHere;
Question asking if the user is new to the platform
In en, this message translates to: 'Are you new here?'
String get newHere;