newToNostr property
String
get
newToNostr
Question asking if the user is new to Nostr
In en, this message translates to: 'New to Nostr?'
Implementation
String get newToNostr;
Question asking if the user is new to Nostr
In en, this message translates to: 'New to Nostr?'
String get newToNostr;