albyGoQrScanInstructions property
Instructions shown beside the Alby Go wallet authorization QR code
In en, this message translates to: 'In Alby Go, tap Send, then scan this QR code.'
Implementation
@override
String get albyGoQrScanInstructions =>
'Tippe in Alby Go auf „Senden“ und scanne dann diesen QR-Code.';