addWalletDescription property
Description for the unified add wallet flow
In en, this message translates to: 'Scan any supported wallet QR code, paste its details, or connect through a wallet app.'
Implementation
@override
String get addWalletDescription =>
'Escanea un código QR de cartera compatible, pega sus datos o conéctate mediante una aplicación de cartera.';