enterQuoteId property

  1. @override
String get enterQuoteId
override

Prompt to enter a mint quote ID

In en, this message translates to: 'Enter the mint quote ID to recover. The lock key is recovered from your seed phrase.'

Implementation

@override
String get enterQuoteId =>
    'Ingresa el ID de la cotización de acuñación a recuperar. La clave de bloqueo se recupera desde tu frase semilla.';