albyGoQrScanInstructions property
Instructions shown beside the Alby Go wallet authorization QR code
In en, this message translates to: 'In Alby Go, tap Send, then scan this QR code.'
Implementation
@override
String get albyGoQrScanInstructions =>
'Napauta Alby Go -sovelluksessa Lähetä ja skannaa sitten tämä QR-koodi.';