bolt12OfferInstructions property

  1. @override
String get bolt12OfferInstructions
override

No description provided for @bolt12OfferInstructions.

In en, this message translates to: 'Share this reusable offer to receive a Lightning payment.'

Implementation

@override
String get bolt12OfferInstructions =>
    'Share this reusable offer to receive a Lightning payment.';