albyGoQrScanInstructions property
Instructions shown beside the Alby Go wallet authorization QR code
In en, this message translates to: 'In Alby Go, tap Send, then scan this QR code.'
Implementation
@override
String get albyGoQrScanInstructions =>
'Dans Alby Go, appuyez sur « Envoyer », puis scannez ce code QR.';