backupSeedInstructions property

  1. @override
String get backupSeedInstructions
override

No description provided for @backupSeedInstructions.

In en, this message translates to: 'Write down these words in order and store them somewhere safe. They are the only way to recover your cashu funds if you lose this device.'

Implementation

@override
String get backupSeedInstructions =>
    'Notez ces mots dans l\'ordre et conservez-les en lieu sûr. C\'est le seul moyen de récupérer vos fonds cashu si vous perdez cet appareil.';