cashuBackupWarning property
Security warning shown in the cashu backup dialog
In en, this message translates to: 'This backup contains your ecash proofs, which are bearer funds. Keep it private and store it somewhere safe. Your seed phrase is backed up separately.'
Implementation
@override
String get cashuBackupWarning =>
'This backup contains your ecash proofs, which are bearer funds. Keep it private and store it somewhere safe. Your seed phrase is backed up separately.';