addWalletDescription property
Description for the unified add wallet flow
In en, this message translates to: 'Scan any supported wallet QR code, paste its details, or connect through a wallet app.'
Implementation
@override
String get addWalletDescription =>
'Scansiona un codice QR di un portafoglio supportato, incolla i dati o connettiti tramite un\'app portafoglio.';