appUpdateAllowInstalls property

  1. @override
String get appUpdateAllowInstalls
override

No description provided for @appUpdateAllowInstalls.

In en, this message translates to: 'Allow installs from this app, then tap Update again.'

Implementation

@override
String get appUpdateAllowInstalls =>
    'Consenti installazioni da questa app, quindi tocca di nuovo Aggiorna.';