nwcFaucetDescription property
String
get
nwcFaucetDescription
override
Description for NWC faucet
In en, this message translates to:
'Create a test wallet with sats from the NWC faucet.'
Implementation
@override
String get nwcFaucetDescription =>
'Crea un portafoglio di test con sats dal faucet NWC.';