backupSeedInstructions property
No description provided for @backupSeedInstructions.
In en, this message translates to: 'Write down these words in order and store them somewhere safe. They are the only way to recover your cashu funds if you lose this device.'
Implementation
@override
String get backupSeedInstructions =>
'これらの単語を順番に書き留め、安全な場所に保管してください。この端末を紛失した場合、cashu資金を復元する唯一の方法です。';