albyGoQrScanInstructions property

  1. @override
String get albyGoQrScanInstructions
override

Instructions shown beside the Alby Go wallet authorization QR code

In en, this message translates to: 'In Alby Go, tap Send, then scan this QR code.'

Implementation

@override
String get albyGoQrScanInstructions =>
    'W Alby Go wybierz „Wyślij”, a następnie zeskanuj ten kod QR.';