backupSeedInstructions property

  1. @override
String get backupSeedInstructions
override

No description provided for @backupSeedInstructions.

In en, this message translates to: 'Write down these words in order and store them somewhere safe. They are the only way to recover your cashu funds if you lose this device.'

Implementation

@override
String get backupSeedInstructions =>
    'Zapisz te słowa w kolejności i przechowuj je w bezpiecznym miejscu. To jedyny sposób na odzyskanie środków cashu w razie utraty tego urządzenia.';