backupSeedInstructions property

  1. @override
String get backupSeedInstructions
override

No description provided for @backupSeedInstructions.

In en, this message translates to: 'Write down these words in order and store them somewhere safe. They are the only way to recover your cashu funds if you lose this device.'

Implementation

@override
String get backupSeedInstructions =>
    'Anote estas palavras em ordem e guarde-as em um lugar seguro. Elas são a única forma de recuperar seus fundos cashu se você perder este dispositivo.';