addWalletDescription property
Description for the unified add wallet flow
In en, this message translates to: 'Scan any supported wallet QR code, paste its details, or connect through a wallet app.'
Implementation
@override
String get addWalletDescription =>
'Escaneie o código QR de uma carteira compatível, cole os dados ou conecte por um aplicativo de carteira.';