backupSeedInstructions property
No description provided for @backupSeedInstructions.
In en, this message translates to: 'Write down these words in order and store them somewhere safe. They are the only way to recover your cashu funds if you lose this device.'
Implementation
@override
String get backupSeedInstructions =>
'Zapíšte si tieto slová v uvedenom poradí a uložte ich na bezpečné miesto. Sú jediným spôsobom, ako obnoviť vaše Cashu prostriedky pri strate tohto zariadenia.';