MethodChannelDartNdk class

An implementation of NdkPlatform that uses method channels.

Inheritance

Constructors

MethodChannelDartNdk()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPublicKey() → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
verifySignature(String signature, String hash, String pubKey) → Future<bool?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited