NdkEventSignerFactory class

Web factory: produces WebEventSigner instances using @noble/curves.

Constructors

NdkEventSignerFactory()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({String? privateKey, String? publicKey}) → EventSigner
Creates an EventSigner instance.
override
createWithNewKeyPair() → EventSigner
Generates a new EventSigner with a fresh keypair.
override
derivePublicKey(String privateKey) String
Derives a public key from a private key. Implementations MUST provide the derivation logic.
override
generateKeyPair() → (String, String)
Generates a new keypair. Returns a record with (privateKey, publicKey).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited