AndroidPackageInstaller class

Inheritance

Constructors

AndroidPackageInstaller()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
progress Stream<double>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelDownload() Future<void>
override
dispose() → void
override
downloadAndInstall(SoftwareAsset asset) Future<UpdateInstallResult>
override
getInstalledSoftware() Future<InstalledSoftware>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited