UpdateInstaller class abstract

Implementers

Constructors

UpdateInstaller()

Properties

hashCode int
The hash code for this object.
no setterinherited
progress Stream<double>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelDownload() Future<void>
dispose() → void
downloadAndInstall(SoftwareAsset asset) Future<UpdateInstallResult>
getInstalledSoftware() Future<InstalledSoftware>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited