NLogin class

Inheritance

Constructors

NLogin({Key? key, required NdkFlutter ndkFlutter, void onLoggedIn()?, bool enableAccountCreation = true, bool enableNip05Login = true, bool enableNpubLogin = true, bool enableNsecLogin = true, bool enableNip07Login = true, bool enableBunkerLogin = true, bool enableSignerAppLogin = true, bool enablePubkeyLogin = true, NostrConnect? nostrConnect, String? nsecLabelText, String getStartedUrl = 'https://nstart.me/'})
const

Properties

enableAccountCreation → bool
final
enableBunkerLogin → bool
final
enableNip05Login → bool
final
enableNip07Login → bool
final
enableNostrConnectLogin → bool
no setter
enableNpubLogin → bool
final
enableNsecLogin → bool
final
enablePubkeyLogin → bool
final
enableSignerAppLogin → bool
final
getStartedUrl → String
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
ndk → Ndk
no setter
ndkFlutter → NdkFlutter
final
nostrConnect → NostrConnect?
final
nsecLabelText → String?
final
onLoggedIn → void Function()?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<NLogin>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited