NPendingRequests class

A widget that displays pending signer requests (for Amber, bunker, extension).

This widget shows a floating panel at the bottom of the screen when there are pending requests waiting for user approval on external signers.

Example usage:

Stack(
  children: [
    YourMainContent(),
    NPendingRequests(ndkFlutter: ndkFlutter),
  ],
)
Inheritance

Constructors

NPendingRequests({Key? key, required NdkFlutter ndkFlutter, double horizontalMargin = 16, double bottomMargin = 16, Duration animationDuration = const Duration(milliseconds: 200), Widget collapsedBuilder(BuildContext context, int count, String signerName)?, Widget expandedBuilder(BuildContext context, List<PendingSignerRequest> requests, String signerName, void onCancel(String requestId))?})
const

Properties

animationDuration Duration
Animation duration
final
bottomMargin double
Bottom margin from screen edge
final
collapsedBuilder Widget Function(BuildContext context, int count, String signerName)?
Custom builder for the collapsed content
final
expandedBuilder Widget Function(BuildContext context, List<PendingSignerRequest> requests, String signerName, void onCancel(String requestId))?
Custom builder for the expanded content
final
hashCode int
The hash code for this object.
no setterinherited
horizontalMargin double
Horizontal margin from screen edges
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
ndkFlutter NdkFlutter
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NPendingRequests>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited