AlbyGoConnectConfig class

Configuration for launching the Alby Go NWC connection intent.

Provide raw (unencoded) values. They will be encoded for the intent URL.

Constructors

AlbyGoConnectConfig({required String appName, required String appIconUrl, required String callback, String discoveryRelay = 'wss://relay.getalby.com', List<NwcMethod> requestMethods = _defaultAlbyGoRequestMethods, String walletName = 'Alby Go', AlbyGoConnectMethod connectMethod = AlbyGoConnectMethod.walletAuth, String walletAuthScheme = 'nostr+walletauth+alby', String nostrNwcScheme = 'nostrnwc+alby', String androidPackage = 'com.getalby.mobile', String nostrNwcHost = 'connect'})
const

Properties

androidPackage → String
final
appIconUrl → String
final
appName → String
final
callback → String
final
connectMethod → AlbyGoConnectMethod
final
discoveryRelay → String
final
hashCode → int
The hash code for this object.
no setterinherited
nostrNwcHost → String
Host used when connectMethod is AlbyGoConnectMethod.nostrNwcCallback.
final
nostrNwcScheme → String
final
requestMethods → List<NwcMethod>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
walletAuthScheme → String
final
walletName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited