CashuMintSuggestion class

Community-rated Cashu mint discovered from signed NIP-87 events.

Constructors

CashuMintSuggestion({required String url, required String name, String? iconUrl, required double? averageRating, required int reviewsCount, List<CashuMintReview> reviews = const []})
const

Properties

averageRating → double?
final
hashCode → int
The hash code for this object.
no setterinherited
iconUrl → String?
final
name → String
final
reviews → List<CashuMintReview>
final
reviewsCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited