WalletInputScannerConfiguration class

Content and actions for a host-provided wallet scanner screen.

Constructors

WalletInputScannerConfiguration({required String supportedInputDescription, required String connectionSectionTitle, required List<WalletScannerConnectionOption> connectionOptions, required ValueListenable<WalletConnectionState> connectionState, required Future<bool> retryPendingConnection(), required VoidCallback cancelPendingConnection, required Future<List<CashuMintSuggestion>> discoverCashuMints(), required Future<CashuMintSuggestion> enrichCashuMint(CashuMintSuggestion suggestion), Future<LnBitsConnectionInput> validateLnBitsConnection(LnBitsConnectionInput input)?, bool openWalletChooserInitially = false, bool openCashuMintChooserInitially = false})
const

Properties

cancelPendingConnection VoidCallback
final
connectionOptions List<WalletScannerConnectionOption>
final
connectionSectionTitle String
final
connectionState ValueListenable<WalletConnectionState>
final
discoverCashuMints Future<List<CashuMintSuggestion>> Function()
final
enrichCashuMint Future<CashuMintSuggestion> Function(CashuMintSuggestion suggestion)
final
hashCode int
The hash code for this object.
no setterinherited
openCashuMintChooserInitially bool
final
openWalletChooserInitially bool
final
retryPendingConnection Future<bool> Function()
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedInputDescription String
final
validateLnBitsConnection Future<LnBitsConnectionInput> Function(LnBitsConnectionInput input)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited