backgroundWidget property
Widget to display as the background decoration If null, the iconWidget will be used with reduced opacity
Implementation
final Widget? backgroundWidget;
Widget to display as the background decoration If null, the iconWidget will be used with reduced opacity
final Widget? backgroundWidget;