NWallets class

High-level wallets section widget that mirrors the sample app's wallets tab.

This keeps built-in English defaults for labels but allows host applications to pass in localized strings (e.g. from AppLocalizations).

Inheritance

Constructors

NWallets({Key? key, required NdkFlutter ndkFlutter, String? title, String? recentActivityTitle, bool showPendingTransactions = true, bool showRecentTransactions = true, bool showAddButtons = true, bool showWalletActions = true, VoidCallback? onAddCashu, VoidCallback? onAddNwc, VoidCallback? onAddLnurl, Widget? header, Widget? headerActions, EdgeInsetsGeometry padding = const EdgeInsets.all(16.0), double walletCardsHeight = 200, Axis walletCardsScrollDirection = Axis.horizontal, double recentTransactionsHeight = 200, ValueChanged<String>? onWalletSelected, AlbyGoConnectConfig albyGoConnectConfig = kDefaultAlbyGoConnectConfig, WalletIconConfig? cashuIcon, WalletIconConfig? nwcIcon, WalletIconConfig? lnurlIcon})
const

Properties

albyGoConnectConfig AlbyGoConnectConfig
Parameters for launching Alby Go NWC connection.
final
cashuIcon WalletIconConfig?
Custom icon configuration for Cashu wallets
final
hashCode int
The hash code for this object.
no setterinherited
Optional widget to replace the entire header row (title + actions).
final
headerActions Widget?
Optional widget to replace just the add-buttons row.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lnurlIcon WalletIconConfig?
Custom icon configuration for LNURL wallets
final
ndkFlutter NdkFlutter
final
nwcIcon WalletIconConfig?
Custom icon configuration for NWC wallets
final
onAddCashu VoidCallback?
Optional callback when add-Cashu button is pressed.
final
onAddLnurl VoidCallback?
Optional callback when add-LNURL button is pressed.
final
onAddNwc VoidCallback?
Optional callback when add-NWC button is pressed.
final
onWalletSelected ValueChanged<String>?
Optional callback when a wallet is selected.
final
padding EdgeInsetsGeometry
Padding around the entire section.
final
recentActivityTitle String?
Title above the recent transactions list.
final
recentTransactionsHeight double
Height of the recent transactions list.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAddButtons bool
Whether to show the add-wallet buttons in the header.
final
showPendingTransactions bool
Whether to show the pending transactions section.
final
showRecentTransactions bool
Whether to show the recent transactions section.
final
showWalletActions bool
Whether to show the wallet operations card for the selected wallet.
final
title String?
Section title above the wallet cards.
final
walletCardsHeight double
Height of the wallet cards list.
final
walletCardsScrollDirection Axis
Scroll direction for the wallet cards list.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NWallets>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited