backupSeedInstructions property
String
get
backupSeedInstructions
No description provided for @backupSeedInstructions.
In en, this message translates to: 'Write down these words in order and store them somewhere safe. They are the only way to recover your cashu funds if you lose this device.'
Implementation
String get backupSeedInstructions;