addWalletDescription property
Description for the unified add wallet flow
In en, this message translates to: 'Scan any supported wallet QR code, paste its details, or connect through a wallet app.'
Implementation
@override
String get addWalletDescription =>
'Scannez un QR code de portefeuille compatible, collez ses informations ou connectez-vous via une application de portefeuille.';