appUpdateAllowInstalls property
No description provided for @appUpdateAllowInstalls.
In en, this message translates to: 'Allow installs from this app, then tap Update again.'
Implementation
@override
String get appUpdateAllowInstalls =>
'Autorisez les installations depuis cette application, puis touchez de nouveau Mettre à jour.';