noCompatibleReceivingWalletsDescription property
No description provided for @noCompatibleReceivingWalletsDescription.
In en, this message translates to: 'Add or connect another wallet that can receive a payment supported by this wallet.'
Implementation
@override
String get noCompatibleReceivingWalletsDescription =>
'Add or connect another wallet that can receive a payment supported by this wallet.';