NdkFlutter class
Constructors
- NdkFlutter({required Ndk ndk, String npubSeparator = '…', int npubPrefixLength = 10, int npubSuffixLength = 4})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ndk → Ndk
-
final
- npubPrefixLength → int
-
final
- npubSeparator → String
-
final
- npubSuffixLength → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
formatNpub(
String pubkey) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
restoreAccountsState(
) → Future< void> -
saveAccountsState(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fetchNip05(
String nip05) → Future< Nip05Result> -
getColorFromPubkey(
String pubkey) → Color