NdkEventVerifier class
A platform-aware event verifier that automatically selects the best implementation for the current platform.
- On web: uses WebEventVerifier, which leverages native Web Crypto APIs for fast signature verification.
- On native platforms (Android, iOS, desktop): uses
RustEventVerifier.
This removes the need for conditional imports or platform checks in application code.
final ndk = Ndk(
NdkConfig(
eventVerifier: NdkEventVerifier(),
cache: MemCacheManager(),
),
);
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
Nip01Event event) → Future< bool> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited