NAppUpdateController class
- Inheritance
-
- Object
- ChangeNotifier
- NAppUpdateController
- Mixed-in types
Constructors
-
NAppUpdateController({required NdkFlutter ndkFlutter, required SoftwareAppRef app, required UpdateInstaller installer, String? currentVersion, Uri? externalUpdateUrl, bool? installationEnabled, SoftwareAppRef? zapTargetApp, String channel = 'main', List<
String> relays = const [], Duration queryTimeout = const Duration(seconds: 5), Duration engagementQueryTimeout = const Duration(seconds: 4), Duration engagementMetadataTimeout = const Duration(seconds: 3)}) -
NAppUpdateController.self({required NdkFlutter ndkFlutter, required SoftwareAppRef app, SoftwareAppRef? zapTargetApp, String? currentVersion, Uri? externalUpdateUrl, bool? installationEnabled, String channel = 'main', List<
String> relays = const [], UpdateInstaller? installer, Duration queryTimeout = const Duration(seconds: 5), Duration engagementQueryTimeout = const Duration(seconds: 4), Duration engagementMetadataTimeout = const Duration(seconds: 3)}) -
factory
Properties
- app → SoftwareAppRef
-
final
- channel → String
-
final
- currentVersion → String?
-
final
- engagementMetadataTimeout → Duration
-
final
- engagementQueryTimeout → Duration
-
final
- externalUpdateUrl → Uri?
-
final
- hasExternalUpdate → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- installationEnabled → bool
-
final
- installer → UpdateInstaller
-
final
- ndkFlutter → NdkFlutter
-
final
- queryTimeout → Duration
-
final
-
relays
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → NAppUpdateState
-
no setter
- zapTargetApp → SoftwareAppRef?
-
final
Methods
-
acknowledgeInstalledRelease(
) → Future< void> -
acquireReleaseWatch(
) → Future< void> -
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
assetForRelease(
SoftwareRelease release) → SoftwareAsset? -
cancelDownload(
) → Future< void> -
checkNow(
{bool allowDuringInstaller = false}) → Future< void> -
didChangeAccessibilityFeatures(
) → void -
Called when the system changes the set of currently active accessibility
features.
inherited
-
didChangeAppLifecycleState(
AppLifecycleState state) → void -
Called when the system puts the app in the background or returns
the app to the foreground.
override
-
didChangeLocales(
List< Locale> ? locales) → void -
Called when the system tells the app that the user's locale has
changed. For example, if the user changes the system language
settings.
inherited
-
didChangeMetrics(
) → void -
Called when the application's dimensions change. For example,
when a phone is rotated.
inherited
-
didChangePlatformBrightness(
) → void -
Called when the platform brightness changes.
inherited
-
didChangeTextScaleFactor(
) → void -
Called when the platform's text scale factor changes.
inherited
-
didChangeViewFocus(
ViewFocusEvent event) → void -
Called whenever the PlatformDispatcher receives a notification that the
focus state on a view has changed.
inherited
-
didHaveMemoryPressure(
) → void -
Called when the system is running low on memory.
inherited
-
didPopRoute(
) → Future< bool> -
Called when the system tells the app to pop the current route, such as
after a system back button press or back gesture.
inherited
-
didPushRoute(
String route) → Future< bool> -
Called when the host tells the application to push a new route onto the
navigator.
inherited
-
didPushRouteInformation(
RouteInformation routeInformation) → Future< bool> -
Called when the host tells the application to push a new
RouteInformation and a restoration state onto the router.
inherited
-
didRequestAppExit(
) → Future< AppExitResponse> -
Called when a request is received from the system to exit the application.
inherited
-
dismiss(
) → Future< void> -
dispose(
) → void -
Discards any resources used by the object.
override
-
downloadAndInstall(
) → Future< void> -
handleCancelBackGesture(
) → void -
Called when a predictive back gesture is canceled, indicating that no
navigation should occur.
inherited
-
handleCommitBackGesture(
) → void -
Called when a predictive back gesture is finished successfully, indicating
that the current route should be popped.
inherited
-
handleStartBackGesture(
PredictiveBackEvent backEvent) → bool -
Called at the start of a predictive back gesture.
inherited
-
handleStatusBarTap(
) → void -
Called when the user taps the status bar on iOS, to scroll a scroll
view to the top.
inherited
-
handleUpdateBackGestureProgress(
PredictiveBackEvent backEvent) → void -
Called when a predictive back gesture moves.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
openExternalUpdate(
) → Future< void> -
releaseReleaseWatch(
) → Future< void> -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
start(
{bool watchReleases = false}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited