NAppUpdateState class

Annotations

Constructors

NAppUpdateState({NAppUpdateStatus status = NAppUpdateStatus.idle, InstalledSoftware? installed, SoftwareUpdate? update, SoftwareRelease? currentRelease, SoftwareRelease? latestRelease, SoftwareRelease? justUpdatedRelease, List<SoftwareRelease> releases = const [], Map<String, List<SoftwareAsset>> assetsByReleaseId = const {}, double? progress, DateTime? lastChecked, String? error})
const

Properties

assetsByReleaseId Map<String, List<SoftwareAsset>>
final
currentRelease → SoftwareRelease?
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
installed → InstalledSoftware?
final
justUpdatedRelease → SoftwareRelease?
final
lastChecked DateTime?
final
latestRelease → SoftwareRelease?
final
progress double?
final
releases List<SoftwareRelease>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status NAppUpdateStatus
final
update → SoftwareUpdate?
final

Methods

copyWith({NAppUpdateStatus? status, InstalledSoftware? installed, SoftwareUpdate? update, SoftwareRelease? currentRelease, SoftwareRelease? latestRelease, SoftwareRelease? justUpdatedRelease, List<SoftwareRelease>? releases, Map<String, List<SoftwareAsset>>? assetsByReleaseId, bool clearJustUpdatedRelease = false, double? progress, bool clearProgress = false, DateTime? lastChecked, String? error, bool clearError = false}) NAppUpdateState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited