NReleaseEngagementController class
- Inheritance
-
- Object
- ChangeNotifier
- NReleaseEngagementController
Constructors
-
NReleaseEngagementController({required Ndk ndk, required SoftwareRelease release, List<
String> relays = const [], SoftwareAppRef? zapTargetApp, Duration queryTimeout = const Duration(seconds: 4), Duration metadataTimeout = const Duration(seconds: 3)})
Properties
- applicationAddress → String
-
no setter
- canComment → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- metadataTimeout → Duration
-
final
- ndk → Ndk
-
final
- queryTimeout → Duration
-
final
-
relays
→ List<
String> -
final
- release → SoftwareRelease
-
final
- releaseAddress → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → NReleaseEngagementState
-
no setter
- zapTargetApp → SoftwareAppRef?
-
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
override
-
load(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
postComment(
String content) → Future< bool> -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited