AlbyGoConnectConfig class

Configuration for launching the Alby Go NWC connection intent.

Provide raw (unencoded) values. They will be encoded for the intent URL.

Constructors

AlbyGoConnectConfig({required String appName, required String appIconUrl, required String callback})
const

Properties

appIconUrl String
final
appName String
final
callback String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited