LnBitsConnectionInput class

Constructors

LnBitsConnectionInput({required String url, required String adminKey, String? walletName, String? remoteWalletId, bool readOnly = false})
const

Properties

adminKey String
final
hashCode int
The hash code for this object.
no setterinherited
readOnly bool
final
remoteWalletId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final
walletName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited