NwcConnectionOption class
Host-provided wallet app or web service that can authorize an NWC connection.
Constructors
- NwcConnectionOption({required String label, required NwcConnectionLauncher connect, String? id, String? subtitle, WidgetBuilder? iconBuilder})
-
const
Properties
- connect → NwcConnectionLauncher
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconBuilder → WidgetBuilder?
-
final
- id → String?
-
final
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited