NWalletCard class

Individual wallet card widget used by the wallets UI.

Inheritance

Constructors

NWalletCard({Key? key, required Wallet wallet, required NdkFlutter ndkFlutter, required bool isSelected, bool isDefaultForReceiving = false, bool isDefaultForSending = false, required VoidCallback onTap, VoidCallback? onDefaultWalletChanged, Future<void> onDelete(BuildContext context, Wallet wallet)?, double width = 280, bool showBudgetRenewalDays = false, WalletIconConfig? cashuIcon, WalletIconConfig? nwcIcon, WalletIconConfig? lnurlIcon})
const

Properties

cashuIcon WalletIconConfig?
Custom icon configuration for Cashu wallets
final
hashCode int
The hash code for this object.
no setterinherited
isDefaultForReceiving bool
final
isDefaultForSending bool
final
isSelected bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lnurlIcon WalletIconConfig?
Custom icon configuration for LNURL wallets
final
ndkFlutter NdkFlutter
final
nwcIcon WalletIconConfig?
Custom icon configuration for NWC wallets
final
onDefaultWalletChanged VoidCallback?
final
onDelete Future<void> Function(BuildContext context, Wallet wallet)?
final
onTap VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBudgetRenewalDays bool
final
wallet → Wallet
final
width double
Width of the card. Defaults to 280.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NWalletCard>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited