WalletIconConfig class

Configuration for wallet type icons

Constructors

WalletIconConfig({Widget? iconWidget, Widget? backgroundWidget, double iconSize = 32, double backgroundSize = 120, double backgroundOpacity = 0.12})
const

Properties

backgroundOpacity double
Opacity of the background decoration (0.0 - 1.0)
final
backgroundSize double
Size of the background decoration
final
backgroundWidget Widget?
Widget to display as the background decoration If null, the iconWidget will be used with reduced opacity
final
hashCode int
The hash code for this object.
no setterinherited
iconSize double
Size of the main icon
final
iconWidget Widget?
Widget to display as the main icon (e.g., in the top left)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited