emptyTitleText property
Optional text to display when there are no wallets. Defaults to an English string; host apps should prefer passing a localized value from AppLocalizations.
Implementation
final String? emptyTitleText;
Optional text to display when there are no wallets. Defaults to an English string; host apps should prefer passing a localized value from AppLocalizations.
final String? emptyTitleText;